# function
compute_features = function(u_id, i_id, inter, users, items, type){
  
  if (type == "for_pred") { 
    
    # find indices
    u_ind = match(u_id, users$id)
    i_ind = match(i_id, items$id)
    
    # number of matches in title ids [Int]
    n_matches_title = sapply(
      str_split(str_c(users$jobroles[u_ind], ",", items$title[i_ind]), ","),
      function(x){sum(duplicated(x))}
    )
    
    # discipline matches [0, 1]
    discipline_matches = (users$discipline_id[u_ind] == items$discipline_id[i_ind])*1
    
    # career level matches [0, 1]
    career_matches = (users$career_level[u_ind] == items$career_level[i_ind])*1
    
    # industry matches [0, 1]
    industry_matches = (users$industry_id[u_ind] == items$industry_id[i_ind])*1
    
    # country match[0, 1]
    country_matches = (users$country[u_ind] == items$country[i_ind])*1
    
    # region match [0, 1]
    region_match = (users$region[u_ind] == items$region[i_ind])*1
    
    result = data.frame(user_id = u_id,
                        item_id = i_id,
                        n_matches_title = n_matches_title,
                        discipline_matches = discipline_matches,
                        career_matches = career_matches,
                        industry_matches = industry_matches,
                        country_matches = country_matches,
                        region_match = region_match,
                        stringsAsFactors = FALSE)
    result[is.na(result)] = FALSE
    
    return(result)
    
  }
  
  else if (type == "for_train") {
    
    # biuld interactions dataset
    interactions = data.frame(user_id = inter$user_id,
                              item_id = inter$item_id,
                              interaction_type = inter$interaction_type_initial,
                              interaction_type_init = inter$interaction_type_initial)
    
    # find indices
    u_ind = match(interactions$user_id, users$id)
    i_ind = match(interactions$item_id, items$id)
    
    # number of matches in title ids [Int]
    interactions$n_matches_title = sapply(
      str_split(str_c(users$jobroles[u_ind], ",", items$title[i_ind]), ","),
      function(x){sum(duplicated(x))}
    )
    
    # discipline matches [0, 1]
    interactions$discipline_matches = ifelse(users$discipline_id[u_ind] == items$discipline_id[i_ind], 2, 0)
    
    # career level matches [0, 1]
    interactions$career_matches = (users$career_level[u_ind] == items$career_level[i_ind])*1
    
    # industry matches [0, 1]
    interactions$industry_matches = (users$industry_id[u_ind] == items$industry_id[i_ind])*1
    
    # country match[0, 1]
    interactions$country_matches = (users$country[u_ind] == items$country[i_ind])*1
    
    # region match [0, 1]
    interactions$region_match = (users$region[u_ind] == items$region[i_ind])*1
    
    #interaction_type 
    interactions$interaction_type = ifelse(interactions$interaction_type > 0 & interactions$interaction_type != 4, 1, 0)
    
    interactions = na.omit(interactions)
    
    return(interactions)
  }
  else {
    print("type should be a character string 'for_pred' or 'for_train'")
  }
}
