# 0 = XING showed this item to a user (= impression)
# 1 = the user clicked on the item
# 2 = the user bookmarked the item on XING
# 3 = the user clicked on the reply button or application form button that is shown on some job postings
# 4 = the user deleted a recommendation from his/her list of recommendation (clicking on "x") which has the effect that the recommendation will no longer been shown to the user and that a new recommendation item will be loaded and displayed to the user
# 5 = a recruiter from the items company showed interest into the user. (e.g. clicked on the profile)

# clicks: user clicked at least once on the pushed recommendation, i.e. multiple clicks won't increase the points (1 point)
# bookmarks/replies: the user bookmarked the item or clicked on the reply button (which guides the user to the application form of the job posting) (5 points)
# recruiter interest: a recruiter who owns the item showed interest into the user (e.g. clicked on the profile) for the given job item (20 points)
# deletes: in case we solely observed that the user delted the item (no click, no bookmark/reply, no recruiter interest), we count the pushed recommendation as negative feedback (-10 points)

# userSuccess scores count double points for premium users.
# if at least one successful push recommendation was created for a given item then this counts 50 points for paid items and 25 for other items.

compute_score = function(prediction, real_interaction, advanced_computation = FALSE, user_id = NULL, item_id = NULL, users = NULL, items = NULL){
  
  score = real_interaction[as.logical(prediction)]
  
  score = ifelse(score == 0, 0,
                 ifelse(score == 1, 1, 
                        ifelse(score == 2 | score == 3, 5,
                               ifelse(score == 4, -10, 
                                      ifelse(score == 5, 10, NA)))))
  
  
  if(advanced_computation){
    user_premium = user_id[as.logical(prediction)]
      
    user_premium = users$premium[match(user_premium, users$id)]
    score = score * (1+user_premium)
    
    item_id = item_id[as.logical(prediction)]
    item_id = item_id[score > 0]
    item_paid = items$is_payed[match(item_id, items$id)]
    
    item_paid = data.frame(item_id = item_id, paid = item_paid)
    item_paid = item_paid[!duplicated(item_paid),]
    
    item_score = ifelse(item_paid$paid == 1, 50, 25)
    score = sum(score, item_score)
  }
  
  return(sum(score))
 
}




